@@ -13,7 +13,6 @@ class Block:
 
 	swing = True
 	key = 'C'
-	instruments = []
 
 	wildness = 0.5
 
@@ -28,9 +27,6 @@ class Block:
 	def get_key(self, iteration):
 		return self.key
 
-	def get_instruments(self, iteration):
-		return self.instruments
-
 	def get_meter(self, iteration, tick):
 		return self.meter
 
