@@ -134,8 +134,6 @@ class Instrument:
 	def record_new_bar(self, state):
 		if hasattr(self, "bar"):
 			self.track + self.bar
-			print self.track
-			print
 		b = Bar()
 		b.set_meter(state["meter"])
 		b.length = 0.0
